Documentation
¶
Overview ¶
Package imgdb ... Is a wrapper database management api for storing and grouping image and avoiding duplicates
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DupFileError ¶
type DupFileError struct {
// contains filtered or unexported fields
}
func (DupFileError) Error ¶
func (this DupFileError) Error() string
Error ... Implements error method for duplicate files
type ImageFile ¶
type ImageFile struct {
gorm.Model
Name string `gorm:"not null;unique"`
Format string `gorm:"not null"`
Index []byte `gorm:"not null"`
Sources []Source
ClusterID int
}
ImageFile ... Specifies name information and image features
type ImgDB ¶
ImgDB ... Is a wrapper gorm for images
func (*ImgDB) AddImg ¶
AddImg ... Extracts image features as search index Save to file system then add in database Filters out images too small beyond a limit Index and logic inspired from https://tinyurl.com/yaup47bg
func (*ImgDB) SourceExists ¶
SourceExists ... Check if there is already an associated link in the database
Click to show internal directories.
Click to hide internal directories.